@@ -571,8 +571,10 @@ def __importModules__():
             for files in modules[modu][submod]:
                 try:
                     module_name = modules[modu][submod][files][0].split(".")[0]
-                    worker("import-module-{m}".format(m=module_name), 'ht.__importModule__', args=(modu, submod, module_name), loop=False, log=False) # Threaded
-                    #__importModule__(modules=modu, category=submod, moduleName=module_name)
+                    if not __amidjango__:
+                        worker("import-module-{m}".format(m=module_name), 'ht.__importModule__', args=(modu, submod, module_name), loop=False, log=False) # Threaded
+                    else:
+                        __importModule__(modules=modu, category=submod, moduleName=module_name)
                 except Exception as e:
                     Logger.printMessage(message='__importModules__', description='{moduleName} File not found: {error}'.format(moduleName=files, error=str(e)), is_error=True)
                     pass
